##  Step 4: Test the Configuration
  1. On the IdP card, choose Test Configuration.
![Screenshot showing the IdP card with the Test Configuration button highlighted.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio6741249b730643f691da2cae7e142650_LowRes.png)
Test Configuration Button
  2. An overlay with instructions appears.
![Screenshot showing the test configuration dialog with instructions and options.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio8d02d416a40847c6a3e92d0debc2d536_LowRes.png)
Test Configuration Dialog
  3. Open a new incognito or private browser window. If this is not possible, consider using another browser where you can start a new session and log in through your SSO provider.
  4. Enter your email and password, then authenticate using multi-factor authentication.
  5. Verify that you're redirected to SAP LeanIX.
  6. In the user menu in the upper-right corner, verify that you have the expected role (Admin).
